const FOLDER = 'folder';
const PAGE = 'page';

const WIKI_COVER_LIST = [
  'wiki-cover-1.jpg',
  'wiki-cover-2.jpg',
  'wiki-cover-3.jpg',
  'wiki-cover-4.jpg',
  'wiki-cover-5.jpg',
  'wiki-cover-6.jpg',
  'wiki-cover-7.jpg',
  'wiki-cover-8.jpg',
  'wiki-cover-9.jpg',
];

const WIKI_RIGHT_PANEL_WIDTH = 'wiki_right_panel_width';

const DEFAULT_PAGE_NAME = 'New page';

export { FOLDER, PAGE, WIKI_COVER_LIST, DEFAULT_PAGE_NAME, WIKI_RIGHT_PANEL_WIDTH };
